pygeodesy.ecefLocals._EcefLocal

Package pygeodesy :: Module ecefLocals :: Class _EcefLocal |
[frames] | no frames]

# Class _EcefLocal

      object --+
               |
    named._Named --+
                   |
                  _EcefLocal

Known Subclasses:
  - ecef.Ecef9Tuple
  - , latlonBase.LatLonBase
  - , cartesianBase.CartesianBase

(INTERNAL) Base class for `CartesianBase`, `Ecef9Tuple` and `LatLonBase`, providing ECEF to local coordinate conversions.

Instance Methods
toAer(self, ltp=None, **Aer_and_kwds) Convert this instance to local Azimuth, Elevation, slant Range (AER) components. |
toEnu(self, ltp=None, **Enu_and_kwds) Convert this instance to local East, North, Up (ENU) components. |
toLocal(self, Xyz=None, ltp=None, **Xyz_kwds) Convert this instance to local components in a local tangent plane (LTP) |
toLtp(self, Ecef=None, **name) Return the local tangent plane (LTP) for this instance. |
toNed(self, ltp=None, **Ned_and_kwds) Convert this instance to local North, East, Down (NED) components. |
toXyz(self, ltp=None, **Xyz_and_kwds) Convert this instance to local X, Y, Z (XYZ) components. |
Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| Ecef Get the ECEF class (EcefKarney), once.
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toAer (self, ltp=None, **Aer_and_kwds) |
Convert this instance to local Azimuth, Elevation, slant Range (AER) components. Arguments: `ltp` - The local tangent plane (LTP) to use (Ltp), overriding this instance' LTP. `Aer_and_kwds` - Optional AER class `Aer=`Aer to use and optionally, additional `Aer` keyword arguments. Returns: An `Aer` instance. Raises: `TypeError` - Invalid `ltp`. See Also: Method toLocal.

### toEnu (self, ltp=None, **Enu_and_kwds) |
Convert this instance to local East, North, Up (ENU) components. Arguments: `ltp` - The local tangent plane (LTP) to use (Ltp), overriding this instance' LTP. `Enu_and_kwds` - Optional ENU class `Enu=`Enu to use and optionally, additional `Enu` keyword arguments. Returns: An `Enu` instance. Raises: `TypeError` - Invalid `ltp`. See Also: Method toLocal.

### toLocal (self, Xyz=None, ltp=None, **Xyz_kwds) |
Convert this instance to local components in a local tangent plane (LTP) Arguments: `Xyz` - Optional local components class (XyzLocal, Aer, Enu, Ned) or `None`. `ltp` - The local tangent plane (LTP) to use (Ltp), overriding this cartesian's LTP. `Xyz_kwds` - Optionally, additional `Xyz` keyword arguments, ignored if `Xyz is None`. Returns: An `Xyz` instance or a Local9Tuple`(x, y, z, lat, lon, height, ltp, ecef, M)` if `Xyz is None` (with `M=None`). Raises: `TypeError` - Invalid `ltp`.

### toLtp (self, Ecef=None, **name) |
Return the local tangent plane (LTP) for this instance. Arguments: `Ecef` - Optional ECEF class (EcefKarney, ... EcefYou), overriding this instance' Ecef. `name` - Optional `name=NN` (`str`). Returns: An `Ltp` instance.

### toNed (self, ltp=None, **Ned_and_kwds) |
Convert this instance to local North, East, Down (NED) components. Arguments: `ltp` - The local tangent plane (LTP) to use (Ltp), overriding this instance' LTP. `Ned_and_kwds` - Optional NED class `Ned=`Ned to use and optionally, additional `Ned` keyword arguments. Returns: An `Ned` instance. Raises: `TypeError` - Invalid `ltp`. See Also: Method toLocal.

### toXyz (self, ltp=None, **Xyz_and_kwds) |
Convert this instance to local X, Y, Z (XYZ) components. Arguments: `ltp` - The local tangent plane (LTP) to use (Ltp), overriding this instance' LTP. `Xyz_and_kwds` - Optional XYZ class `Xyz=`Xyz to use and optionally, additional `Xyz` keyword arguments. Returns: An `Xyz` instance. Raises: `TypeError` - Invalid `ltp`. See Also: Method toLocal.

Property Details

### Ecef Get the ECEF class (EcefKarney), once. Get method: _fget(inst) - Get the `property` value once and overwrite `self`, this `property` instance in the (super-)class of `self` where this property is define as a property_ROver. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(*unused) - Silently ignored, always.